@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import warnings
+
 from tencentcloud.common.abstract_model import AbstractModel
 
 
@@ -43,6 +45,13 @@ class AssessQualityRequest(AbstractModel):
     def _deserialize(self, params):
         self.ImageUrl = params.get("ImageUrl")
         self.ImageBase64 = params.get("ImageBase64")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class AssessQualityResponse(AbstractModel):
@@ -134,6 +143,13 @@ class CarTagItem(AbstractModel):
                 obj = Coord()
                 obj._deserialize(item)
                 self.CarLocation.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class Coord(AbstractModel):
@@ -155,6 +171,13 @@ class Coord(AbstractModel):
     def _deserialize(self, params):
         self.X = params.get("X")
         self.Y = params.get("Y")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CropImageRequest(AbstractModel):
@@ -196,6 +219,13 @@ Width : Height建议取值在[1, 2.5]之间，超过这个范围可能会影响
         self.Height = params.get("Height")
         self.ImageUrl = params.get("ImageUrl")
         self.ImageBase64 = params.get("ImageBase64")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CropImageResponse(AbstractModel):
@@ -278,6 +308,13 @@ class DetectCelebrityRequest(AbstractModel):
     def _deserialize(self, params):
         self.ImageUrl = params.get("ImageUrl")
         self.ImageBase64 = params.get("ImageBase64")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DetectCelebrityResponse(AbstractModel):
@@ -343,6 +380,13 @@ class DetectDisgustRequest(AbstractModel):
     def _deserialize(self, params):
         self.ImageUrl = params.get("ImageUrl")
         self.ImageBase64 = params.get("ImageBase64")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DetectDisgustResponse(AbstractModel):
@@ -370,6 +414,133 @@ class DetectDisgustResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DetectLabelBetaRequest(AbstractModel):
+    """DetectLabelBeta请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param ImageUrl: 图片URL地址。 
+图片限制： 
+• 图片格式：PNG、JPG、JPEG。 
+• 图片大小：所下载图片经Base64编码后不超过4M。图片下载时间不超过3秒。 
+建议：
+• 图片像素：大于50*50像素，否则影响识别效果； 
+• 长宽比：长边：短边<5； 
+接口响应时间会受到图片下载时间的影响，建议使用更可靠的存储服务，推荐将图片存储在腾讯云COS。
+        :type ImageUrl: str
+        :param ImageBase64: 图片经过base64编码的内容。最大不超过4M。与ImageUrl同时存在时优先使用ImageUrl字段。
+**注意：图片需要base64编码，并且要去掉编码头部。**
+        :type ImageBase64: str
+        :param Scenes: 本次调用支持的识别场景，可选值如下：
+WEB，针对网络图片优化;
+CAMERA，针对手机摄像头拍摄图片优化;
+ALBUM，针对手机相册、网盘产品优化;
+NEWS，针对新闻、资讯、广电等行业优化；
+NONECAM，非实拍图；
+LOCATION，主体位置识别；
+如果不传此参数，则默认为WEB。
+
+支持多场景（Scenes）一起检测。例如，使用 Scenes=["WEB", "CAMERA"]，即对一张图片使用两个模型同时检测，输出两套识别结果。
+        :type Scenes: list of str
+        """
+        self.ImageUrl = None
+        self.ImageBase64 = None
+        self.Scenes = None
+
+
+    def _deserialize(self, params):
+        self.ImageUrl = params.get("ImageUrl")
+        self.ImageBase64 = params.get("ImageBase64")
+        self.Scenes = params.get("Scenes")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DetectLabelBetaResponse(AbstractModel):
+    """DetectLabelBeta返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param Labels: Web网络版标签结果数组。如未选择WEB场景，则为空。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Labels: list of DetectLabelItem
+        :param CameraLabels: Camera摄像头版标签结果数组。如未选择CAMERA场景，则为空。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type CameraLabels: list of DetectLabelItem
+        :param AlbumLabels: Album相册版标签结果数组。如未选择ALBUM场景，则为空。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type AlbumLabels: list of DetectLabelItem
+        :param NewsLabels: News新闻版标签结果数组。如未选择NEWS场景，则为空。
+新闻版目前为测试阶段，暂不提供每个标签的一级、二级分类信息的输出。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type NewsLabels: list of DetectLabelItem
+        :param NoneCamLabels: 非实拍标签
+注意：此字段可能返回 null，表示取不到有效值。
+        :type NoneCamLabels: list of DetectLabelItem
+        :param LocationLabels: 识别结果
+注意：此字段可能返回 null，表示取不到有效值。
+        :type LocationLabels: list of Product
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.Labels = None
+        self.CameraLabels = None
+        self.AlbumLabels = None
+        self.NewsLabels = None
+        self.NoneCamLabels = None
+        self.LocationLabels = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("Labels") is not None:
+            self.Labels = []
+            for item in params.get("Labels"):
+                obj = DetectLabelItem()
+                obj._deserialize(item)
+                self.Labels.append(obj)
+        if params.get("CameraLabels") is not None:
+            self.CameraLabels = []
+            for item in params.get("CameraLabels"):
+                obj = DetectLabelItem()
+                obj._deserialize(item)
+                self.CameraLabels.append(obj)
+        if params.get("AlbumLabels") is not None:
+            self.AlbumLabels = []
+            for item in params.get("AlbumLabels"):
+                obj = DetectLabelItem()
+                obj._deserialize(item)
+                self.AlbumLabels.append(obj)
+        if params.get("NewsLabels") is not None:
+            self.NewsLabels = []
+            for item in params.get("NewsLabels"):
+                obj = DetectLabelItem()
+                obj._deserialize(item)
+                self.NewsLabels.append(obj)
+        if params.get("NoneCamLabels") is not None:
+            self.NoneCamLabels = []
+            for item in params.get("NoneCamLabels"):
+                obj = DetectLabelItem()
+                obj._deserialize(item)
+                self.NoneCamLabels.append(obj)
+        if params.get("LocationLabels") is not None:
+            self.LocationLabels = []
+            for item in params.get("LocationLabels"):
+                obj = Product()
+                obj._deserialize(item)
+                self.LocationLabels.append(obj)
+        self.RequestId = params.get("RequestId")
+
+
 class DetectLabelItem(AbstractModel):
     """图像标签检测结果。
 
@@ -397,6 +568,13 @@ class DetectLabelItem(AbstractModel):
         self.Confidence = params.get("Confidence")
         self.FirstCategory = params.get("FirstCategory")
         self.SecondCategory = params.get("SecondCategory")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DetectLabelRequest(AbstractModel):
@@ -437,6 +615,13 @@ NEWS，针对新闻、资讯、广电等行业优化；
         self.ImageUrl = params.get("ImageUrl")
         self.ImageBase64 = params.get("ImageBase64")
         self.Scenes = params.get("Scenes")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DetectLabelResponse(AbstractModel):
@@ -524,6 +709,13 @@ class DetectMisbehaviorRequest(AbstractModel):
     def _deserialize(self, params):
         self.ImageUrl = params.get("ImageUrl")
         self.ImageBase64 = params.get("ImageBase64")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DetectMisbehaviorResponse(AbstractModel):
@@ -572,6 +764,13 @@ class DetectProductBetaRequest(AbstractModel):
     def _deserialize(self, params):
         self.ImageUrl = params.get("ImageUrl")
         self.ImageBase64 = params.get("ImageBase64")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DetectProductBetaResponse(AbstractModel):
@@ -588,11 +787,15 @@ class DetectProductBetaResponse(AbstractModel):
         :param ProductInfo: 图像识别出的商品的详细信息。 
 当图像中检测到多个物品时，会对显著性最高的进行识别。
         :type ProductInfo: :class:`tencentcloud.tiia.v20190529.models.ProductInfo`
+        :param ProductInfoList: 相似商品信息列表
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ProductInfoList: list of ProductInfo
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self.RegionDetected = None
         self.ProductInfo = None
+        self.ProductInfoList = None
         self.RequestId = None
 
 
@@ -606,6 +809,12 @@ class DetectProductBetaResponse(AbstractModel):
         if params.get("ProductInfo") is not None:
             self.ProductInfo = ProductInfo()
             self.ProductInfo._deserialize(params.get("ProductInfo"))
+        if params.get("ProductInfoList") is not None:
+            self.ProductInfoList = []
+            for item in params.get("ProductInfoList"):
+                obj = ProductInfo()
+                obj._deserialize(item)
+                self.ProductInfoList.append(obj)
         self.RequestId = params.get("RequestId")
 
 
@@ -636,6 +845,13 @@ class DetectProductRequest(AbstractModel):
     def _deserialize(self, params):
         self.ImageUrl = params.get("ImageUrl")
         self.ImageBase64 = params.get("ImageBase64")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DetectProductResponse(AbstractModel):
@@ -691,6 +907,13 @@ class EnhanceImageRequest(AbstractModel):
     def _deserialize(self, params):
         self.ImageUrl = params.get("ImageUrl")
         self.ImageBase64 = params.get("ImageBase64")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class EnhanceImageResponse(AbstractModel):
@@ -767,6 +990,13 @@ class Face(AbstractModel):
         self.Width = params.get("Width")
         self.Height = params.get("Height")
         self.ID = params.get("ID")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class Labels(AbstractModel):
@@ -790,6 +1020,13 @@ class Labels(AbstractModel):
     def _deserialize(self, params):
         self.FirstLabel = params.get("FirstLabel")
         self.SecondLabel = params.get("SecondLabel")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class Location(AbstractModel):
@@ -819,6 +1056,13 @@ class Location(AbstractModel):
         self.YMin = params.get("YMin")
         self.XMax = params.get("XMax")
         self.YMax = params.get("YMax")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class Product(AbstractModel):
@@ -860,6 +1104,13 @@ class Product(AbstractModel):
         self.YMin = params.get("YMin")
         self.XMax = params.get("XMax")
         self.YMax = params.get("YMax")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ProductInfo(AbstractModel):
@@ -912,6 +1163,13 @@ class ProductInfo(AbstractModel):
         self.ProductCategory = params.get("ProductCategory")
         self.Score = params.get("Score")
         self.Image = params.get("Image")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class RecognizeCarRequest(AbstractModel):
@@ -942,6 +1200,13 @@ class RecognizeCarRequest(AbstractModel):
     def _deserialize(self, params):
         self.ImageUrl = params.get("ImageUrl")
         self.ImageBase64 = params.get("ImageBase64")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class RecognizeCarResponse(AbstractModel):
@@ -1007,6 +1272,13 @@ class RegionDetected(AbstractModel):
         if params.get("Location") is not None:
             self.Location = Location()
             self.Location._deserialize(params.get("Location"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class Threshold(AbstractModel):
@@ -1034,4 +1306,11 @@ class Threshold(AbstractModel):
     def _deserialize(self, params):
         self.FalseRate1Percent = params.get("FalseRate1Percent")
         self.FalseRate5Permil = params.get("FalseRate5Permil")
-        self.FalseRate1Permil = params.get("FalseRate1Permil")
\ No newline at end of file
+        self.FalseRate1Permil = params.get("FalseRate1Permil")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
\ No newline at end of file
